@@ -4,7 +4,7 @@ from django.conf.urls import patterns
 from . import views
 
 urlpatterns = patterns('',
-    (r'^$', 'django.shortcuts.render', {'template_name': 'grappelli_te/index.html'}),
+    (r'^$', views.index),
     (r'^list/$', views.template_list),
     (r'^open/$', views.template_detail),
 )
